@@ -746,6 +746,14 @@ sub _min_max
     return( $code >= $min && $code < $max );
 }
 
+# NOTE: sub FREEZE is inherited
+
+sub STORABLE_freeze { CORE::return( CORE::shift->FREEZE( @_ ) ); }
+
+sub STORABLE_thaw { CORE::return( CORE::shift->THAW( @_ ) ); }
+
+# NOTE: sub THAW is inherited
+
 1;
 # NOTE: POD
 __END__
